@@ -3,7 +3,7 @@ from django.conf import settings
 from django import forms
 from django_rest_webhooks.utils import get_hook_model
 
-if getattr(settings, 'HOOK_EVENTS', None) is None:
+if getattr(settings, "HOOK_EVENTS", None) is None:
     raise Exception("You need to define settings.HOOK_EVENTS!")
 
 
@@ -19,20 +19,22 @@ class HookForm(forms.ModelForm):
 
     class Meta:
         model = HookModel
-        fields = ['user', 'target', 'event']
+        fields = ["user", "target", "event"]
 
     def __init__(self, *args, **kwargs):
         super(HookForm, self).__init__(*args, **kwargs)
-        self.fields['event'] = forms.ChoiceField(choices=self.get_admin_events())
+        self.fields["event"] = forms.ChoiceField(choices=self.get_admin_events())
 
     @classmethod
     def get_admin_events(cls):
-        return [(x, x) for x in getattr(settings, 'HOOK_EVENTS', None).keys()]
+        return [(x, x) for x in getattr(settings, "HOOK_EVENTS", None).keys()]
 
 
 class HookAdmin(admin.ModelAdmin):
     list_display = [f.name for f in HookModel._meta.fields]
-    raw_id_fields = ['user', ]
+    raw_id_fields = [
+        "user",
+    ]
     form = HookForm
 
 
